@@ -194,7 +194,7 @@ def root():
     init()
 
     try:
-        with open('~/tradocs.config.json', 'r') as file:
+        with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'r') as file:
             configs = json.load(file)
         print(configs)
         apiTradKey = configs['TRANSLATOR_KEY']
@@ -210,7 +210,7 @@ def root():
             'SOURCE': sourceLang,
             'TARGET': targetLangs
         }
-        with open('~/tradocs.config.json', 'w') as file:
+        with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'w+') as file:
             json.dump(configs, file)
 
     if sourceDir not in os.listdir():
